# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/client_peers.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/client_peers.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\013client_peer'),
  serialized_pb=_b('\n#dgt_sdk/protobuf/client_peers.proto\"\x87\x01\n\x15\x43lientPeersGetRequest\x12-\n\x06status\x18\x01 \x01(\x0e\x32\x1d.ClientPeersGetRequest.Status\"?\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\r\n\tMALICIOUS\x10\x01\x12\x0e\n\nMALICIOUS1\x10\x02\x12\x0e\n\nMALICIOUS2\x10\x03\"\x86\x01\n\x16\x43lientPeersGetResponse\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.ClientPeersGetResponse.Status\x12\r\n\x05peers\x18\x02 \x03(\t\"-\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"\x8f\x01\n\x19\x43lientPeersControlRequest\x12.\n\x04mode\x18\x01 \x01(\x0e\x32 .ClientPeersControlRequest.Modes\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x0c\n\x04peer\x18\x03 \x01(\t\"#\n\x05Modes\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\x12\x08\n\x04INFO\x10\x02\"{\n\x1a\x43lientPeersControlResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".ClientPeersControlResponse.Status\x12\x0c\n\x04info\x18\x02 \x01(\t\"\x1b\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x42&\n\x15sawtooth.sdk.protobufP\x01Z\x0b\x63lient_peerb\x06proto3')
)



_CLIENTPEERSGETREQUEST_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientPeersGetRequest.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALICIOUS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALICIOUS1', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALICIOUS2', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=112,
  serialized_end=175,
)
_sym_db.RegisterEnumDescriptor(_CLIENTPEERSGETREQUEST_STATUS)

_CLIENTPEERSGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientPeersGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=267,
  serialized_end=312,
)
_sym_db.RegisterEnumDescriptor(_CLIENTPEERSGETRESPONSE_STATUS)

_CLIENTPEERSCONTROLREQUEST_MODES = _descriptor.EnumDescriptor(
  name='Modes',
  full_name='ClientPeersControlRequest.Modes',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UP', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=423,
  serialized_end=458,
)
_sym_db.RegisterEnumDescriptor(_CLIENTPEERSCONTROLREQUEST_MODES)

_CLIENTPEERSCONTROLRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientPeersControlResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=556,
  serialized_end=583,
)
_sym_db.RegisterEnumDescriptor(_CLIENTPEERSCONTROLRESPONSE_STATUS)


_CLIENTPEERSGETREQUEST = _descriptor.Descriptor(
  name='ClientPeersGetRequest',
  full_name='ClientPeersGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientPeersGetRequest.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTPEERSGETREQUEST_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=175,
)


_CLIENTPEERSGETRESPONSE = _descriptor.Descriptor(
  name='ClientPeersGetResponse',
  full_name='ClientPeersGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientPeersGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peers', full_name='ClientPeersGetResponse.peers', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTPEERSGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=312,
)


_CLIENTPEERSCONTROLREQUEST = _descriptor.Descriptor(
  name='ClientPeersControlRequest',
  full_name='ClientPeersControlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='ClientPeersControlRequest.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='ClientPeersControlRequest.cluster', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer', full_name='ClientPeersControlRequest.peer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTPEERSCONTROLREQUEST_MODES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=315,
  serialized_end=458,
)


_CLIENTPEERSCONTROLRESPONSE = _descriptor.Descriptor(
  name='ClientPeersControlResponse',
  full_name='ClientPeersControlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientPeersControlResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='ClientPeersControlResponse.info', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTPEERSCONTROLRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=583,
)

_CLIENTPEERSGETREQUEST.fields_by_name['status'].enum_type = _CLIENTPEERSGETREQUEST_STATUS
_CLIENTPEERSGETREQUEST_STATUS.containing_type = _CLIENTPEERSGETREQUEST
_CLIENTPEERSGETRESPONSE.fields_by_name['status'].enum_type = _CLIENTPEERSGETRESPONSE_STATUS
_CLIENTPEERSGETRESPONSE_STATUS.containing_type = _CLIENTPEERSGETRESPONSE
_CLIENTPEERSCONTROLREQUEST.fields_by_name['mode'].enum_type = _CLIENTPEERSCONTROLREQUEST_MODES
_CLIENTPEERSCONTROLREQUEST_MODES.containing_type = _CLIENTPEERSCONTROLREQUEST
_CLIENTPEERSCONTROLRESPONSE.fields_by_name['status'].enum_type = _CLIENTPEERSCONTROLRESPONSE_STATUS
_CLIENTPEERSCONTROLRESPONSE_STATUS.containing_type = _CLIENTPEERSCONTROLRESPONSE
DESCRIPTOR.message_types_by_name['ClientPeersGetRequest'] = _CLIENTPEERSGETREQUEST
DESCRIPTOR.message_types_by_name['ClientPeersGetResponse'] = _CLIENTPEERSGETRESPONSE
DESCRIPTOR.message_types_by_name['ClientPeersControlRequest'] = _CLIENTPEERSCONTROLREQUEST
DESCRIPTOR.message_types_by_name['ClientPeersControlResponse'] = _CLIENTPEERSCONTROLRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientPeersGetRequest = _reflection.GeneratedProtocolMessageType('ClientPeersGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTPEERSGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_peers_pb2'
  # @@protoc_insertion_point(class_scope:ClientPeersGetRequest)
  ))
_sym_db.RegisterMessage(ClientPeersGetRequest)

ClientPeersGetResponse = _reflection.GeneratedProtocolMessageType('ClientPeersGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTPEERSGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_peers_pb2'
  # @@protoc_insertion_point(class_scope:ClientPeersGetResponse)
  ))
_sym_db.RegisterMessage(ClientPeersGetResponse)

ClientPeersControlRequest = _reflection.GeneratedProtocolMessageType('ClientPeersControlRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTPEERSCONTROLREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_peers_pb2'
  # @@protoc_insertion_point(class_scope:ClientPeersControlRequest)
  ))
_sym_db.RegisterMessage(ClientPeersControlRequest)

ClientPeersControlResponse = _reflection.GeneratedProtocolMessageType('ClientPeersControlResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTPEERSCONTROLRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_peers_pb2'
  # @@protoc_insertion_point(class_scope:ClientPeersControlResponse)
  ))
_sym_db.RegisterMessage(ClientPeersControlResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import sys
import ipaddress as ip
import base64
import os
import configparser
import time
from client import cli
from client.VER import __version__


def valIP(nodeIP: str) -> None:
    try:
        nodeIP = nodeIP.replace("http://","")
        nodeIP= nodeIP.split(":",1)[0]
        ip_obj = ip.ip_address(nodeIP) #Creates IP object using the ipaddress module, which automatically throws a value error if the IP is improper
    except ValueError:
        print("Invalid IP")
        sys.exit()

def valPort(port: str) -> None:
    try:
        port = int(port)
        if port < 0 or port > 65535: raise ValueError
    except ValueError:
        print("Invalid Port. Please enter IP:PORT")
        sys.exit()

#Simple helper method to see if opening a file is possible
def valFile(path:str) -> None:
    try:
        f= open (path)
    except OSError:
        print("Something went wrong reading the file")
        sys.exit()

def valOut(path:str) -> None:
    try:
        f=open(path, 'w')
    except FileNotFoundError:
        print("Error making output file")
        sys.exit()

#Method to validate the arguments passed in
def valArgs(args:list) -> None:
    try:
        valid_commands = [ "version" , "connect" , "set" , "inc" ,"dec" , "trans",
                            "show", "list" , "execute" , "exit","key","validator", "output" ]

        if args[1].lower().strip() not in valid_commands : raise NameError

        if len(args) < 3 and 'list' not in args and 'version' not in args : raise IndexError

        if (args[1] == "connect" or args[1]=="output") and len(args) != 3:
            raise IndexError

        if args[1] in ["dec","inc","set","trans"]:
            if args[1] != "trans" and len(args) != 4 and len(args)!= 5 : raise IndexError
            config.read("config/config.ini")
            user_info = config["user_info"]
            global PK_path
            PK_path = user_info["pk_path"]

            if args[1] != "trans" : 
                valToken(args[3])
                if len(args)==5: #If the length of the arg list is 5, and it's valid it means that the user passed in a wait parameter
                    valWait(args[4])
                    time.sleep(int(args[4]))
            else: 
                if len(args) != 6 and len(args)!=5 : raise IndexError
                
                valToken(args[4])
                if len(args)==6 : 
                    valWait(args[5]) #Wait Parameter 
                    time.sleep(int(args[5]))
            
        if args[1] == "show" :
            if len(args)!=3 and len(args)!=4 :raise IndexError
            if len(args) == 4: 
                valWait(args[3]) #Wait Paramater
                time.sleep(int(args[3]))

        if args[1] == "list":
            if len(args)!=2 and len(args)!=3: raise IndexError
            if len(args) == 3:
                valWait(args[2])
                time.sleep(int(args[3]))
        
        if args[1] == "output" :
            valOut(args[2])

    except IndexError:
        print("Invalid number of arguments.")
        sys.exit()
    except NameError:
        print("Invalid Command")
        sys.exit()
    except KeyError:
        print("No Private Key found, add it with bgtc key [PATH]")
        sys.exit()
#Runs on the first "connect" command, requires seperate logic from updating IP
def initIP():
    try:
       connect = arguments[1]
       if connect != "connect" : raise NameError
       if len(arguments) > 3  : raise IndexError
      #TODO: Add support for https and SSH  
       valIP(arguments[2])
       
       if ":" not in arguments[2]:
           print("Please provide Port")
           sys.exit()

       valPort(arguments[2].split(":",1)[1])

       config.add_section("user_info")
       config.set("user_info", "node_ip" , arguments[2])
       
       if not os.path.isdir("config"): os.makedirs("config") 
       with open("config/config.ini","w") as file:
           config.write(file)
   
    except IndexError:
        print("Invalid number of arguments")
        sys.exit()
    except NameError:
        print('Not connected to any Node, run "bgtc connect"')
        sys.exit()
    except OSError:
        print("Something went wrong when writing the config file")
        sys.exit()
        
def updateIP(socket:str) -> None:
    config.read("config/config.ini")
    user_info = config["user_info"]
    
    ip_port=socket.split(":",1)
    valIP(ip_port[0])
    valPort(ip_port[1])

    user_info["node_ip"] = socket
    try:
        with open("config/config.ini","w") as cf:
            config.write(cf)
    except OSError:
        print("Someting went wrong modifing the config file")
        sys.exit()

def setOutput(out: str):
    config.read("config/config.ini")
    if not config.has_option("user_info","output") : config.set("user_info","output",os.path.abspath(out))
    else : config["user_info"]["output"] =  os.path.abspath(out)

    with open("config/config.ini","w") as cf:
        config.write(cf)


def getKey(path: str) -> str :
    try:
        print(path)
        with open(path) as f:
            KF = f.read().strip()
            f.close()
        KF = KF.replace("-----BEGIN EC PRIVATE KEY-----","") #OPENSSL adds these lines to the top and bottom, we want to to remove them
        KF = KF.replace("-----END EC PRIVATE KEY-----" , "")
        KF= base64.b64decode(KF).hex()
        return KF
    except OSError as e:
        print("Failed to Read Private Key")
        sys.exit()
        

def writeKey(path:str):
    #We don't do any verifing here, since it should have already been verified
    #by valArgs and getKey
    config.read("config/config.ini")
    
    if not config.has_option("user_info","pk_path"):
        config.set("user_info", "pk_path",os.path.abspath(path))
    else:
        config["user_info"]["pk_path"] = os.path.abspath(path)
    with open("config/config.ini","w") as cf:
        config.write(cf)
    
def valWait(wait:str):
    try:
        wait=int(wait)
        if wait <0 or wait > 70: raise ValueError
    except ValueError:
        print("Wait must be an integer between 0 and 70")
        sys.exit()

def valToken(token:str):
    try:
        token=int(token)
        if token <0 or token > 2**32 -1 : raise ValueError
    except ValueError:
        print("Token must be a non-negative integer between 0 and 2^32")
        sys.exit()


def out(result):
    if config.has_option("user_option", "output") : 
            with open(config["user_option"]["output"],'w') as f:
                f.write(result)
                sys.exit()
    else: 
        print("flag")
        print(result) 


def main():
    try:
        if sys.argv[1] =="execute":
            file = open(sys.argv[2] , 'r')
            lines = file.readlines()
            for l in lines : 
                run(l.split( " "))
        else:
            run(sys.argv)
    except IndexError:
        run(sys.argv)
#Runs the command passed into it
def run(args:list):
    global arguments
    arguments=args
    global config
    config = configparser.ConfigParser()
    
    valArgs(arguments)

    #These commands do not require to be connected to any Node
    if arguments[1] == "version":
        print(__version__)
        sys.exit()
    if arguments[1] == "output" :
        setOutput(args[2])
        print ("output set")
        sys.exit


    if not os.path.isfile("config/config.ini"): initIP()
     
    if arguments[1] == "key" : 
        global PK
        writeKey(arguments[2])
        sys.exit()
    
    if arguments[1] == "validator" :
        valFile("config/config.ini")
        config.set("user_info","validator_ip",arguments[2])
        with open("config/config.ini","w") as cf:
            config.write(cf)


    config.read("config/config.ini")

    #Perhaps upgarading to Python 3.10 for the match statment is worth it
    if arguments[1] == "connect" : 
        updateIP(arguments[2])
        nodeIP=arguments[2].split(":",1)
        
        #It's important to note that the socket doesn't stay open after the program exits.
        errno=cli.connect(nodeIP[0], int(nodeIP[1]))

        if errno != 0 : 
            print(f"Something went wrong. Errno:{errno}") 
            sys.exit()
        print("Sucessfully connected.")
    
    if arguments[1] in ["inc","dec","set","trans"]:
        if arguments[1] == "trans" : 
            to = arguments[3]
            val = arguments[4]
        else: 
            to = None
            val = arguments[3]
        PK=getKey(PK_path)
        result = cli.send(IP= config["user_info"]["node_ip"].replace("http://","") \
                , verb =arguments[1] , wal = arguments[2], value =val, PK=PK, to=to )
        out(result)
           
    if arguments[1] == "show" : cli.show(config["user_info"]["node_ip"],arguments[2])
    if arguments[1] == "exit" : sys.exit()
    if arguments[1] == "list":
        config.read("config/config.ini")
        if not config.has_option("user_info","validator_ip"):
            print("Validator IP has not been set. Please run the 'validator' command \
                    followed by the IP of the validator. The deafult validator is \
                    'tcp://validator-dgt-c1-1:8108' , please consult the documentarion (section 3.2) \
                    for how to find the validator ip.")
        sys.exit()
        cli.List(config["user_info"]["node_ip"].replace("http://",""),config["user_info"]["validator_ip"])
  

if __name__ == '__main__':
        main() 



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/client_list_control.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/client_list_control.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\027client_list_control_pb2'),
  serialized_pb=_b('\n*dgt_sdk/protobuf/client_list_control.proto\"4\n\x14\x43lientPagingControls\x12\r\n\x05start\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\"B\n\x14\x43lientPagingResponse\x12\x0c\n\x04next\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x05\"3\n\x12\x43lientSortControls\x12\x0c\n\x04keys\x18\x01 \x03(\t\x12\x0f\n\x07reverse\x18\x02 \x01(\x08\x42\x32\n\x15sawtooth.sdk.protobufP\x01Z\x17\x63lient_list_control_pb2b\x06proto3')
)




_CLIENTPAGINGCONTROLS = _descriptor.Descriptor(
  name='ClientPagingControls',
  full_name='ClientPagingControls',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='ClientPagingControls.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='ClientPagingControls.limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=98,
)


_CLIENTPAGINGRESPONSE = _descriptor.Descriptor(
  name='ClientPagingResponse',
  full_name='ClientPagingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='next', full_name='ClientPagingResponse.next', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='ClientPagingResponse.start', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='ClientPagingResponse.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=166,
)


_CLIENTSORTCONTROLS = _descriptor.Descriptor(
  name='ClientSortControls',
  full_name='ClientSortControls',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='ClientSortControls.keys', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reverse', full_name='ClientSortControls.reverse', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=168,
  serialized_end=219,
)

DESCRIPTOR.message_types_by_name['ClientPagingControls'] = _CLIENTPAGINGCONTROLS
DESCRIPTOR.message_types_by_name['ClientPagingResponse'] = _CLIENTPAGINGRESPONSE
DESCRIPTOR.message_types_by_name['ClientSortControls'] = _CLIENTSORTCONTROLS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientPagingControls = _reflection.GeneratedProtocolMessageType('ClientPagingControls', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTPAGINGCONTROLS,
  __module__ = 'dgt_sdk.protobuf.client_list_control_pb2'
  # @@protoc_insertion_point(class_scope:ClientPagingControls)
  ))
_sym_db.RegisterMessage(ClientPagingControls)

ClientPagingResponse = _reflection.GeneratedProtocolMessageType('ClientPagingResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTPAGINGRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_list_control_pb2'
  # @@protoc_insertion_point(class_scope:ClientPagingResponse)
  ))
_sym_db.RegisterMessage(ClientPagingResponse)

ClientSortControls = _reflection.GeneratedProtocolMessageType('ClientSortControls', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTSORTCONTROLS,
  __module__ = 'dgt_sdk.protobuf.client_list_control_pb2'
  # @@protoc_insertion_point(class_scope:ClientSortControls)
  ))
_sym_db.RegisterMessage(ClientSortControls)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/client_heads.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/client_heads.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\013client_head'),
  serialized_pb=_b('\n#dgt_sdk/protobuf/client_heads.proto\"(\n\x15\x43lientHeadsGetRequest\x12\x0f\n\x07head_id\x18\x01 \x01(\t\"\x86\x01\n\x16\x43lientHeadsGetResponse\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.ClientHeadsGetResponse.Status\x12\r\n\x05heads\x18\x02 \x03(\t\"-\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\"$\n\x12\x44\x61gGraphGetRequest\x12\x0e\n\x06\x66ormat\x18\x01 \x01(\t\"\x80\x01\n\x13\x44\x61gGraphGetResponse\x12+\n\x06status\x18\x01 \x01(\x0e\x32\x1b.DagGraphGetResponse.Status\x12\r\n\x05graph\x18\x02 \x01(\t\"-\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x42&\n\x15sawtooth.sdk.protobufP\x01Z\x0b\x63lient_headb\x06proto3')
)



_CLIENTHEADSGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientHeadsGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=171,
  serialized_end=216,
)
_sym_db.RegisterEnumDescriptor(_CLIENTHEADSGETRESPONSE_STATUS)

_DAGGRAPHGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='DagGraphGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=171,
  serialized_end=216,
)
_sym_db.RegisterEnumDescriptor(_DAGGRAPHGETRESPONSE_STATUS)


_CLIENTHEADSGETREQUEST = _descriptor.Descriptor(
  name='ClientHeadsGetRequest',
  full_name='ClientHeadsGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='head_id', full_name='ClientHeadsGetRequest.head_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=79,
)


_CLIENTHEADSGETRESPONSE = _descriptor.Descriptor(
  name='ClientHeadsGetResponse',
  full_name='ClientHeadsGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientHeadsGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heads', full_name='ClientHeadsGetResponse.heads', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTHEADSGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=216,
)


_DAGGRAPHGETREQUEST = _descriptor.Descriptor(
  name='DagGraphGetRequest',
  full_name='DagGraphGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='format', full_name='DagGraphGetRequest.format', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=254,
)


_DAGGRAPHGETRESPONSE = _descriptor.Descriptor(
  name='DagGraphGetResponse',
  full_name='DagGraphGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='DagGraphGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='graph', full_name='DagGraphGetResponse.graph', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DAGGRAPHGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=257,
  serialized_end=385,
)

_CLIENTHEADSGETRESPONSE.fields_by_name['status'].enum_type = _CLIENTHEADSGETRESPONSE_STATUS
_CLIENTHEADSGETRESPONSE_STATUS.containing_type = _CLIENTHEADSGETRESPONSE
_DAGGRAPHGETRESPONSE.fields_by_name['status'].enum_type = _DAGGRAPHGETRESPONSE_STATUS
_DAGGRAPHGETRESPONSE_STATUS.containing_type = _DAGGRAPHGETRESPONSE
DESCRIPTOR.message_types_by_name['ClientHeadsGetRequest'] = _CLIENTHEADSGETREQUEST
DESCRIPTOR.message_types_by_name['ClientHeadsGetResponse'] = _CLIENTHEADSGETRESPONSE
DESCRIPTOR.message_types_by_name['DagGraphGetRequest'] = _DAGGRAPHGETREQUEST
DESCRIPTOR.message_types_by_name['DagGraphGetResponse'] = _DAGGRAPHGETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientHeadsGetRequest = _reflection.GeneratedProtocolMessageType('ClientHeadsGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTHEADSGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_heads_pb2'
  # @@protoc_insertion_point(class_scope:ClientHeadsGetRequest)
  ))
_sym_db.RegisterMessage(ClientHeadsGetRequest)

ClientHeadsGetResponse = _reflection.GeneratedProtocolMessageType('ClientHeadsGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTHEADSGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_heads_pb2'
  # @@protoc_insertion_point(class_scope:ClientHeadsGetResponse)
  ))
_sym_db.RegisterMessage(ClientHeadsGetResponse)

DagGraphGetRequest = _reflection.GeneratedProtocolMessageType('DagGraphGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _DAGGRAPHGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_heads_pb2'
  # @@protoc_insertion_point(class_scope:DagGraphGetRequest)
  ))
_sym_db.RegisterMessage(DagGraphGetRequest)

DagGraphGetResponse = _reflection.GeneratedProtocolMessageType('DagGraphGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _DAGGRAPHGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_heads_pb2'
  # @@protoc_insertion_point(class_scope:DagGraphGetResponse)
  ))
_sym_db.RegisterMessage(DagGraphGetResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/pbft_consensus.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dgt_sdk.protobuf import consensus_pb2 as dgt__sdk_dot_protobuf_dot_consensus__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/pbft_consensus.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n%dgt_sdk/protobuf/pbft_consensus.proto\x1a dgt_sdk/protobuf/consensus.proto\"[\n\x10PbftBlockMessage\x12\x10\n\x08\x62lock_id\x18\x01 \x01(\x0c\x12\x11\n\tsigner_id\x18\x03 \x01(\x0c\x12\x11\n\tblock_num\x18\x04 \x01(\x04\x12\x0f\n\x07summary\x18\x06 \x01(\x0c\"\x98\x02\n\x0fPbftMessageInfo\x12\x32\n\x08msg_type\x18\x01 \x01(\x0e\x32 .PbftMessageInfo.PbftMessageType\x12\x0c\n\x04view\x18\x02 \x01(\x04\x12\x0f\n\x07seq_num\x18\x03 \x01(\x04\x12\x11\n\tsigner_id\x18\x04 \x01(\x0c\"\x9e\x01\n\x0fPbftMessageType\x12\x13\n\x0fPRE_PREPARE_MSG\x10\x00\x12\x0f\n\x0bPREPARE_MSG\x10\x01\x12\x0e\n\nCOMMIT_MSG\x10\x02\x12\x12\n\x0e\x43HECKPOINT_MSG\x10\x03\x12\x12\n\x0eVIEWCHANGE_MSG\x10\x04\x12\x13\n\x0f\x41RBITRATION_MSG\x10\x05\x12\x18\n\x14\x41RBITRATION_DONE_MSG\x10\x06\">\n\x0bPbftMessage\x12\x1e\n\x04info\x18\x01 \x01(\x0b\x32\x10.PbftMessageInfo\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"0\n\x0ePbftViewChange\x12\x1e\n\x04info\x18\x01 \x01(\x0b\x32\x10.PbftMessageInfo\"=\n\x0bPbftNewView\x12.\n\x0cview_changes\x18\x01 \x03(\x0b\x32\x18.ConsensusPeerMessageNew\"W\n\x0ePbftSignedVote\x12\x14\n\x0cheader_bytes\x18\x01 \x01(\x0c\x12\x18\n\x10header_signature\x18\x02 \x01(\x0c\x12\x15\n\rmessage_bytes\x18\x03 \x01(\x0c\"\\\n\x08PbftSeal\x12 \n\x05\x62lock\x18\x01 \x01(\x0b\x32\x11.PbftBlockMessage\x12.\n\x0c\x63ommit_votes\x18\x02 \x03(\x0b\x32\x18.ConsensusPeerMessageNewb\x06proto3')
  ,
  dependencies=[dgt__sdk_dot_protobuf_dot_consensus__pb2.DESCRIPTOR,])



_PBFTMESSAGEINFO_PBFTMESSAGETYPE = _descriptor.EnumDescriptor(
  name='PbftMessageType',
  full_name='PbftMessageInfo.PbftMessageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PRE_PREPARE_MSG', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PREPARE_MSG', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMIT_MSG', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHECKPOINT_MSG', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIEWCHANGE_MSG', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARBITRATION_MSG', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARBITRATION_DONE_MSG', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=291,
  serialized_end=449,
)
_sym_db.RegisterEnumDescriptor(_PBFTMESSAGEINFO_PBFTMESSAGETYPE)


_PBFTBLOCKMESSAGE = _descriptor.Descriptor(
  name='PbftBlockMessage',
  full_name='PbftBlockMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_id', full_name='PbftBlockMessage.block_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer_id', full_name='PbftBlockMessage.signer_id', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_num', full_name='PbftBlockMessage.block_num', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary', full_name='PbftBlockMessage.summary', index=3,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=166,
)


_PBFTMESSAGEINFO = _descriptor.Descriptor(
  name='PbftMessageInfo',
  full_name='PbftMessageInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg_type', full_name='PbftMessageInfo.msg_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view', full_name='PbftMessageInfo.view', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq_num', full_name='PbftMessageInfo.seq_num', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer_id', full_name='PbftMessageInfo.signer_id', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PBFTMESSAGEINFO_PBFTMESSAGETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=449,
)


_PBFTMESSAGE = _descriptor.Descriptor(
  name='PbftMessage',
  full_name='PbftMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='PbftMessage.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='PbftMessage.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=513,
)


_PBFTVIEWCHANGE = _descriptor.Descriptor(
  name='PbftViewChange',
  full_name='PbftViewChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='PbftViewChange.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=515,
  serialized_end=563,
)


_PBFTNEWVIEW = _descriptor.Descriptor(
  name='PbftNewView',
  full_name='PbftNewView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='view_changes', full_name='PbftNewView.view_changes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=565,
  serialized_end=626,
)


_PBFTSIGNEDVOTE = _descriptor.Descriptor(
  name='PbftSignedVote',
  full_name='PbftSignedVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_bytes', full_name='PbftSignedVote.header_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_signature', full_name='PbftSignedVote.header_signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_bytes', full_name='PbftSignedVote.message_bytes', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=628,
  serialized_end=715,
)


_PBFTSEAL = _descriptor.Descriptor(
  name='PbftSeal',
  full_name='PbftSeal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='PbftSeal.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit_votes', full_name='PbftSeal.commit_votes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=717,
  serialized_end=809,
)

_PBFTMESSAGEINFO.fields_by_name['msg_type'].enum_type = _PBFTMESSAGEINFO_PBFTMESSAGETYPE
_PBFTMESSAGEINFO_PBFTMESSAGETYPE.containing_type = _PBFTMESSAGEINFO
_PBFTMESSAGE.fields_by_name['info'].message_type = _PBFTMESSAGEINFO
_PBFTVIEWCHANGE.fields_by_name['info'].message_type = _PBFTMESSAGEINFO
_PBFTNEWVIEW.fields_by_name['view_changes'].message_type = dgt__sdk_dot_protobuf_dot_consensus__pb2._CONSENSUSPEERMESSAGENEW
_PBFTSEAL.fields_by_name['block'].message_type = _PBFTBLOCKMESSAGE
_PBFTSEAL.fields_by_name['commit_votes'].message_type = dgt__sdk_dot_protobuf_dot_consensus__pb2._CONSENSUSPEERMESSAGENEW
DESCRIPTOR.message_types_by_name['PbftBlockMessage'] = _PBFTBLOCKMESSAGE
DESCRIPTOR.message_types_by_name['PbftMessageInfo'] = _PBFTMESSAGEINFO
DESCRIPTOR.message_types_by_name['PbftMessage'] = _PBFTMESSAGE
DESCRIPTOR.message_types_by_name['PbftViewChange'] = _PBFTVIEWCHANGE
DESCRIPTOR.message_types_by_name['PbftNewView'] = _PBFTNEWVIEW
DESCRIPTOR.message_types_by_name['PbftSignedVote'] = _PBFTSIGNEDVOTE
DESCRIPTOR.message_types_by_name['PbftSeal'] = _PBFTSEAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PbftBlockMessage = _reflection.GeneratedProtocolMessageType('PbftBlockMessage', (_message.Message,), dict(
  DESCRIPTOR = _PBFTBLOCKMESSAGE,
  __module__ = 'dgt_sdk.protobuf.pbft_consensus_pb2'
  # @@protoc_insertion_point(class_scope:PbftBlockMessage)
  ))
_sym_db.RegisterMessage(PbftBlockMessage)

PbftMessageInfo = _reflection.GeneratedProtocolMessageType('PbftMessageInfo', (_message.Message,), dict(
  DESCRIPTOR = _PBFTMESSAGEINFO,
  __module__ = 'dgt_sdk.protobuf.pbft_consensus_pb2'
  # @@protoc_insertion_point(class_scope:PbftMessageInfo)
  ))
_sym_db.RegisterMessage(PbftMessageInfo)

PbftMessage = _reflection.GeneratedProtocolMessageType('PbftMessage', (_message.Message,), dict(
  DESCRIPTOR = _PBFTMESSAGE,
  __module__ = 'dgt_sdk.protobuf.pbft_consensus_pb2'
  # @@protoc_insertion_point(class_scope:PbftMessage)
  ))
_sym_db.RegisterMessage(PbftMessage)

PbftViewChange = _reflection.GeneratedProtocolMessageType('PbftViewChange', (_message.Message,), dict(
  DESCRIPTOR = _PBFTVIEWCHANGE,
  __module__ = 'dgt_sdk.protobuf.pbft_consensus_pb2'
  # @@protoc_insertion_point(class_scope:PbftViewChange)
  ))
_sym_db.RegisterMessage(PbftViewChange)

PbftNewView = _reflection.GeneratedProtocolMessageType('PbftNewView', (_message.Message,), dict(
  DESCRIPTOR = _PBFTNEWVIEW,
  __module__ = 'dgt_sdk.protobuf.pbft_consensus_pb2'
  # @@protoc_insertion_point(class_scope:PbftNewView)
  ))
_sym_db.RegisterMessage(PbftNewView)

PbftSignedVote = _reflection.GeneratedProtocolMessageType('PbftSignedVote', (_message.Message,), dict(
  DESCRIPTOR = _PBFTSIGNEDVOTE,
  __module__ = 'dgt_sdk.protobuf.pbft_consensus_pb2'
  # @@protoc_insertion_point(class_scope:PbftSignedVote)
  ))
_sym_db.RegisterMessage(PbftSignedVote)

PbftSeal = _reflection.GeneratedProtocolMessageType('PbftSeal', (_message.Message,), dict(
  DESCRIPTOR = _PBFTSEAL,
  __module__ = 'dgt_sdk.protobuf.pbft_consensus_pb2'
  # @@protoc_insertion_point(class_scope:PbftSeal)
  ))
_sym_db.RegisterMessage(PbftSeal)


# @@protoc_insertion_point(module_scope)



# Copyright 2016 DGT NETWORK INC © Stanislav Parsov
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ------------------------------------------------------------------------------

from threading import Condition
from threading import RLock

from dgt_sdk.messaging.exceptions import ValidatorConnectionError
from dgt_sdk.protobuf import validator_pb2


class FutureResult:
    def __init__(self, message_type, content):
        self.message_type = message_type
        self.content = content


class FutureError:
    """Used when resolving a future, to
    set the FutureResult to an error result.
    Specifically this raises ValidatorConnectionError
    when accessing attributes, but can be made more general.
    """

    @property
    def content(self):
        raise ValidatorConnectionError()

    @property
    def message_type(self):
        raise ValidatorConnectionError()


class Future:
    def __init__(self, correlation_id, request_type=None):
        self.correlation_id = correlation_id
        self._result = None
        self._condition = Condition()
        self._request_type = request_type

    def done(self):
        return self._result is not None

    def result(self, timeout=None):
        with self._condition:
            if self._result is None:
                if not self._condition.wait(timeout):
                    message_type = validator_pb2.Message.MessageType.Name(
                        self._request_type) if self._request_type else None
                    raise FutureTimeoutError(
                        'Future timed out waiting for response to {}'.format(
                            message_type))
        return self._result

    def set_result(self, result):
        with self._condition:
            self._result = result
            self._condition.notify()


class FutureCollectionKeyError(Exception):
    pass


class FutureTimeoutError(Exception):
    pass


class FutureCollection:
    def __init__(self):
        self._futures = {}
        self._lock = RLock()

    def put(self, future):
        with self._lock:
            self._futures[future.correlation_id] = future

    def set_result(self, correlation_id, result):
        with self._lock:
            future = self.get(correlation_id)
            future.set_result(result)

    def get(self, correlation_id):
        with self._lock:
            if correlation_id not in self._futures:
                raise FutureCollectionKeyError(
                    "no such correlation id: {}".format(correlation_id))
            return self._futures[correlation_id]

    def remove(self, correlation_id):
        with self._lock:
            if correlation_id not in self._futures:
                raise FutureCollectionKeyError(
                    "no such correlation id: {}".format(correlation_id))
            del self._futures[correlation_id]

    def future_values(self):
        with self._lock:
            return self._futures.values()



# Copyright 2017 DGT NETWORK INC © Stanislav Parsov
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ------------------------------------------------------------------------------

import logging
import logging.config
import os
import sys

from colorlog import ColoredFormatter

class LogWriter(object):
    def __init__(self, logger, level):
        self.logger = logger
        self.level = level

    def write(self, line):
        if line != '\n':
            self.logger.log(self.level, line.rstrip())
def create_console_handler(verbose_level):
    """
    Set up the console logging for a transaction processor.
    Args:
        verbose_level (int): The log level that the console should print out
    """
    clog = logging.StreamHandler()
    formatter = ColoredFormatter(
        "%(log_color)s[%(asctime)s.%(msecs)03d "
        "%(levelname)-8s %(module)s]%(reset)s "
        "%(white)s%(message)s",
        datefmt="%Y-%m-%d %H:%M:%S",
        reset=True,
        log_colors={
            'DEBUG': 'cyan',
            'INFO': 'green',
            'WARNING': 'yellow',
            'ERROR': 'red',
            'CRITICAL': 'red',
        })

    clog.setFormatter(formatter)

    if verbose_level == 0:
        clog.setLevel(logging.WARN)
    elif verbose_level == 1:
        clog.setLevel(logging.INFO)
    else:
        clog.setLevel(logging.DEBUG)

    return clog


def init_console_logging(verbose_level=2,capture_std_output=False):
    """
    Set up the console logging for a transaction processor.
    Args:
        verbose_level (int): The log level that the console should print out
    """
    logger = logging.getLogger()
    logger.setLevel(logging.DEBUG)
    logger.addHandler(create_console_handler(verbose_level))
    if capture_std_output:
        sys.stdout = LogWriter(logging.getLogger("STDOUT"), logging.INFO)
        sys.stderr = LogWriter(logging.getLogger("STDERR"), logging.ERROR)

def log_configuration(log_config=None, log_dir=None, name=None):
    """
    Sets up the loggers for a transaction processor.
    Args:
        log_config (dict): A dictinary of log config options
        log_dir (string): The log directory's path
        name (string): The name of the expected logging file
    """
    if log_config is not None:
        logging.config.dictConfig(log_config)
    else:
        log_filename = os.path.join(log_dir, name)
        debug_handler = logging.FileHandler(log_filename + "-debug.log")
        debug_handler.setFormatter(logging.Formatter(
            '[%(asctime)s.%(msecs)03d [%(threadName)s] %(module)s'
            ' %(levelname)s] %(message)s', "%H:%M:%S"))
        debug_handler.setLevel(logging.DEBUG)

        error_handler = logging.FileHandler(log_filename + "-error.log")
        error_handler.setFormatter(logging.Formatter(
            '[%(asctime)s.%(msecs)03d [%(threadName)s] %(module)s'
            ' %(levelname)s] %(message)s', "%H:%M:%S"))
        error_handler.setLevel(logging.ERROR)

        logging.getLogger().addHandler(error_handler)
        logging.getLogger().addHandler(debug_handler)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/block.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dgt_sdk.protobuf import batch_pb2 as dgt__sdk_dot_protobuf_dot_batch__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/block.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\tblock_pb2'),
  serialized_pb=_b('\n\x1c\x64gt_sdk/protobuf/block.proto\x1a\x1c\x64gt_sdk/protobuf/batch.proto\"\x95\x01\n\x0b\x42lockHeader\x12\x11\n\tblock_num\x18\x01 \x01(\x04\x12\x19\n\x11previous_block_id\x18\x02 \x01(\t\x12\x19\n\x11signer_public_key\x18\x03 \x01(\t\x12\x11\n\tbatch_ids\x18\x04 \x03(\t\x12\x11\n\tconsensus\x18\x05 \x01(\x0c\x12\x17\n\x0fstate_root_hash\x18\x06 \x01(\t\"J\n\x05\x42lock\x12\x0e\n\x06header\x18\x01 \x01(\x0c\x12\x18\n\x10header_signature\x18\x02 \x01(\t\x12\x17\n\x07\x62\x61tches\x18\x03 \x03(\x0b\x32\x06.BatchB$\n\x15sawtooth.sdk.protobufP\x01Z\tblock_pb2b\x06proto3')
  ,
  dependencies=[dgt__sdk_dot_protobuf_dot_batch__pb2.DESCRIPTOR,])




_BLOCKHEADER = _descriptor.Descriptor(
  name='BlockHeader',
  full_name='BlockHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_num', full_name='BlockHeader.block_num', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_block_id', full_name='BlockHeader.previous_block_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer_public_key', full_name='BlockHeader.signer_public_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch_ids', full_name='BlockHeader.batch_ids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consensus', full_name='BlockHeader.consensus', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state_root_hash', full_name='BlockHeader.state_root_hash', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=212,
)


_BLOCK = _descriptor.Descriptor(
  name='Block',
  full_name='Block',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='Block.header', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_signature', full_name='Block.header_signature', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batches', full_name='Block.batches', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=288,
)

_BLOCK.fields_by_name['batches'].message_type = dgt__sdk_dot_protobuf_dot_batch__pb2._BATCH
DESCRIPTOR.message_types_by_name['BlockHeader'] = _BLOCKHEADER
DESCRIPTOR.message_types_by_name['Block'] = _BLOCK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BlockHeader = _reflection.GeneratedProtocolMessageType('BlockHeader', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKHEADER,
  __module__ = 'dgt_sdk.protobuf.block_pb2'
  # @@protoc_insertion_point(class_scope:BlockHeader)
  ))
_sym_db.RegisterMessage(BlockHeader)

Block = _reflection.GeneratedProtocolMessageType('Block', (_message.Message,), dict(
  DESCRIPTOR = _BLOCK,
  __module__ = 'dgt_sdk.protobuf.block_pb2'
  # @@protoc_insertion_point(class_scope:Block)
  ))
_sym_db.RegisterMessage(Block)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/client_batch.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dgt_sdk.protobuf import batch_pb2 as dgt__sdk_dot_protobuf_dot_batch__pb2
from dgt_sdk.protobuf import client_list_control_pb2 as dgt__sdk_dot_protobuf_dot_client__list__control__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/client_batch.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\020client_batch_pb2'),
  serialized_pb=_b('\n#dgt_sdk/protobuf/client_batch.proto\x1a\x1c\x64gt_sdk/protobuf/batch.proto\x1a*dgt_sdk/protobuf/client_list_control.proto\"\x89\x01\n\x16\x43lientBatchListRequest\x12\x0f\n\x07head_id\x18\x01 \x01(\t\x12\x11\n\tbatch_ids\x18\x02 \x03(\t\x12%\n\x06paging\x18\x03 \x01(\x0b\x32\x15.ClientPagingControls\x12$\n\x07sorting\x18\x04 \x03(\x0b\x32\x13.ClientSortControls\"\xb7\x02\n\x17\x43lientBatchListResponse\x12/\n\x06status\x18\x01 \x01(\x0e\x32\x1f.ClientBatchListResponse.Status\x12\x17\n\x07\x62\x61tches\x18\x02 \x03(\x0b\x32\x06.Batch\x12\x0f\n\x07head_id\x18\x03 \x01(\t\x12%\n\x06paging\x18\x04 \x01(\x0b\x32\x15.ClientPagingResponse\"\x99\x01\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x12\n\x0eINTERNAL_ERROR\x10\x02\x12\r\n\tNOT_READY\x10\x03\x12\x0b\n\x07NO_ROOT\x10\x04\x12\x0f\n\x0bNO_RESOURCE\x10\x05\x12\x12\n\x0eINVALID_PAGING\x10\x06\x12\x10\n\x0cINVALID_SORT\x10\x07\x12\x0e\n\nINVALID_ID\x10\x08\")\n\x15\x43lientBatchGetRequest\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\t\"\xb8\x01\n\x16\x43lientBatchGetResponse\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.ClientBatchGetResponse.Status\x12\x15\n\x05\x62\x61tch\x18\x02 \x01(\x0b\x32\x06.Batch\"W\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x12\n\x0eINTERNAL_ERROR\x10\x02\x12\x0f\n\x0bNO_RESOURCE\x10\x05\x12\x0e\n\nINVALID_ID\x10\x08\x42+\n\x15sawtooth.sdk.protobufP\x01Z\x10\x63lient_batch_pb2b\x06proto3')
  ,
  dependencies=[dgt__sdk_dot_protobuf_dot_batch__pb2.DESCRIPTOR,dgt__sdk_dot_protobuf_dot_client__list__control__pb2.DESCRIPTOR,])



_CLIENTBATCHLISTRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientBatchListResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_ROOT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_RESOURCE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PAGING', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_SORT', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ID', index=8, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=412,
  serialized_end=565,
)
_sym_db.RegisterEnumDescriptor(_CLIENTBATCHLISTRESPONSE_STATUS)

_CLIENTBATCHGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientBatchGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_RESOURCE', index=3, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ID', index=4, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=708,
  serialized_end=795,
)
_sym_db.RegisterEnumDescriptor(_CLIENTBATCHGETRESPONSE_STATUS)


_CLIENTBATCHLISTREQUEST = _descriptor.Descriptor(
  name='ClientBatchListRequest',
  full_name='ClientBatchListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='head_id', full_name='ClientBatchListRequest.head_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch_ids', full_name='ClientBatchListRequest.batch_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paging', full_name='ClientBatchListRequest.paging', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sorting', full_name='ClientBatchListRequest.sorting', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=251,
)


_CLIENTBATCHLISTRESPONSE = _descriptor.Descriptor(
  name='ClientBatchListResponse',
  full_name='ClientBatchListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientBatchListResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batches', full_name='ClientBatchListResponse.batches', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='head_id', full_name='ClientBatchListResponse.head_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paging', full_name='ClientBatchListResponse.paging', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTBATCHLISTRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=565,
)


_CLIENTBATCHGETREQUEST = _descriptor.Descriptor(
  name='ClientBatchGetRequest',
  full_name='ClientBatchGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch_id', full_name='ClientBatchGetRequest.batch_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=608,
)


_CLIENTBATCHGETRESPONSE = _descriptor.Descriptor(
  name='ClientBatchGetResponse',
  full_name='ClientBatchGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientBatchGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch', full_name='ClientBatchGetResponse.batch', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTBATCHGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=611,
  serialized_end=795,
)

_CLIENTBATCHLISTREQUEST.fields_by_name['paging'].message_type = dgt__sdk_dot_protobuf_dot_client__list__control__pb2._CLIENTPAGINGCONTROLS
_CLIENTBATCHLISTREQUEST.fields_by_name['sorting'].message_type = dgt__sdk_dot_protobuf_dot_client__list__control__pb2._CLIENTSORTCONTROLS
_CLIENTBATCHLISTRESPONSE.fields_by_name['status'].enum_type = _CLIENTBATCHLISTRESPONSE_STATUS
_CLIENTBATCHLISTRESPONSE.fields_by_name['batches'].message_type = dgt__sdk_dot_protobuf_dot_batch__pb2._BATCH
_CLIENTBATCHLISTRESPONSE.fields_by_name['paging'].message_type = dgt__sdk_dot_protobuf_dot_client__list__control__pb2._CLIENTPAGINGRESPONSE
_CLIENTBATCHLISTRESPONSE_STATUS.containing_type = _CLIENTBATCHLISTRESPONSE
_CLIENTBATCHGETRESPONSE.fields_by_name['status'].enum_type = _CLIENTBATCHGETRESPONSE_STATUS
_CLIENTBATCHGETRESPONSE.fields_by_name['batch'].message_type = dgt__sdk_dot_protobuf_dot_batch__pb2._BATCH
_CLIENTBATCHGETRESPONSE_STATUS.containing_type = _CLIENTBATCHGETRESPONSE
DESCRIPTOR.message_types_by_name['ClientBatchListRequest'] = _CLIENTBATCHLISTREQUEST
DESCRIPTOR.message_types_by_name['ClientBatchListResponse'] = _CLIENTBATCHLISTRESPONSE
DESCRIPTOR.message_types_by_name['ClientBatchGetRequest'] = _CLIENTBATCHGETREQUEST
DESCRIPTOR.message_types_by_name['ClientBatchGetResponse'] = _CLIENTBATCHGETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientBatchListRequest = _reflection.GeneratedProtocolMessageType('ClientBatchListRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTBATCHLISTREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_batch_pb2'
  # @@protoc_insertion_point(class_scope:ClientBatchListRequest)
  ))
_sym_db.RegisterMessage(ClientBatchListRequest)

ClientBatchListResponse = _reflection.GeneratedProtocolMessageType('ClientBatchListResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTBATCHLISTRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_batch_pb2'
  # @@protoc_insertion_point(class_scope:ClientBatchListResponse)
  ))
_sym_db.RegisterMessage(ClientBatchListResponse)

ClientBatchGetRequest = _reflection.GeneratedProtocolMessageType('ClientBatchGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTBATCHGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_batch_pb2'
  # @@protoc_insertion_point(class_scope:ClientBatchGetRequest)
  ))
_sym_db.RegisterMessage(ClientBatchGetRequest)

ClientBatchGetResponse = _reflection.GeneratedProtocolMessageType('ClientBatchGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTBATCHGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_batch_pb2'
  # @@protoc_insertion_point(class_scope:ClientBatchGetResponse)
  ))
_sym_db.RegisterMessage(ClientBatchGetResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/client_receipt.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dgt_sdk.protobuf import transaction_receipt_pb2 as dgt__sdk_dot_protobuf_dot_transaction__receipt__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/client_receipt.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\022client_receipt_pb2'),
  serialized_pb=_b('\n%dgt_sdk/protobuf/client_receipt.proto\x1a*dgt_sdk/protobuf/transaction_receipt.proto\"\x87\x01\n\x17\x43lientReceiptGetRequest\x12+\n\x03ind\x18\x01 \x01(\x0e\x32\x1e.ClientReceiptGetRequest.Index\x12\x17\n\x0ftransaction_ids\x18\x02 \x03(\t\"&\n\x05Index\x12\r\n\tINDEX_TNX\x10\x00\x12\x0e\n\nINDEX_ADDR\x10\x01\"\xcc\x01\n\x18\x43lientReceiptGetResponse\x12\x30\n\x06status\x18\x01 \x01(\x0e\x32 .ClientReceiptGetResponse.Status\x12%\n\x08receipts\x18\x02 \x03(\x0b\x32\x13.TransactionReceipt\"W\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x12\n\x0eINTERNAL_ERROR\x10\x02\x12\x0f\n\x0bNO_RESOURCE\x10\x05\x12\x0e\n\nINVALID_ID\x10\x08\x42-\n\x15sawtooth.sdk.protobufP\x01Z\x12\x63lient_receipt_pb2b\x06proto3')
  ,
  dependencies=[dgt__sdk_dot_protobuf_dot_transaction__receipt__pb2.DESCRIPTOR,])



_CLIENTRECEIPTGETREQUEST_INDEX = _descriptor.EnumDescriptor(
  name='Index',
  full_name='ClientReceiptGetRequest.Index',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INDEX_TNX', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INDEX_ADDR', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=183,
  serialized_end=221,
)
_sym_db.RegisterEnumDescriptor(_CLIENTRECEIPTGETREQUEST_INDEX)

_CLIENTRECEIPTGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientReceiptGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_RESOURCE', index=3, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ID', index=4, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=341,
  serialized_end=428,
)
_sym_db.RegisterEnumDescriptor(_CLIENTRECEIPTGETRESPONSE_STATUS)


_CLIENTRECEIPTGETREQUEST = _descriptor.Descriptor(
  name='ClientReceiptGetRequest',
  full_name='ClientReceiptGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ind', full_name='ClientReceiptGetRequest.ind', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_ids', full_name='ClientReceiptGetRequest.transaction_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTRECEIPTGETREQUEST_INDEX,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=221,
)


_CLIENTRECEIPTGETRESPONSE = _descriptor.Descriptor(
  name='ClientReceiptGetResponse',
  full_name='ClientReceiptGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientReceiptGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receipts', full_name='ClientReceiptGetResponse.receipts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTRECEIPTGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=428,
)

_CLIENTRECEIPTGETREQUEST.fields_by_name['ind'].enum_type = _CLIENTRECEIPTGETREQUEST_INDEX
_CLIENTRECEIPTGETREQUEST_INDEX.containing_type = _CLIENTRECEIPTGETREQUEST
_CLIENTRECEIPTGETRESPONSE.fields_by_name['status'].enum_type = _CLIENTRECEIPTGETRESPONSE_STATUS
_CLIENTRECEIPTGETRESPONSE.fields_by_name['receipts'].message_type = dgt__sdk_dot_protobuf_dot_transaction__receipt__pb2._TRANSACTIONRECEIPT
_CLIENTRECEIPTGETRESPONSE_STATUS.containing_type = _CLIENTRECEIPTGETRESPONSE
DESCRIPTOR.message_types_by_name['ClientReceiptGetRequest'] = _CLIENTRECEIPTGETREQUEST
DESCRIPTOR.message_types_by_name['ClientReceiptGetResponse'] = _CLIENTRECEIPTGETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientReceiptGetRequest = _reflection.GeneratedProtocolMessageType('ClientReceiptGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTRECEIPTGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_receipt_pb2'
  # @@protoc_insertion_point(class_scope:ClientReceiptGetRequest)
  ))
_sym_db.RegisterMessage(ClientReceiptGetRequest)

ClientReceiptGetResponse = _reflection.GeneratedProtocolMessageType('ClientReceiptGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTRECEIPTGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_receipt_pb2'
  # @@protoc_insertion_point(class_scope:ClientReceiptGetResponse)
  ))
_sym_db.RegisterMessage(ClientReceiptGetResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/genesis.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dgt_sdk.protobuf import batch_pb2 as dgt__sdk_dot_protobuf_dot_batch__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/genesis.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\013genesis_pb2'),
  serialized_pb=_b('\n\x1e\x64gt_sdk/protobuf/genesis.proto\x1a\x1c\x64gt_sdk/protobuf/batch.proto\"&\n\x0bGenesisData\x12\x17\n\x07\x62\x61tches\x18\x01 \x03(\x0b\x32\x06.BatchB&\n\x15sawtooth.sdk.protobufP\x01Z\x0bgenesis_pb2b\x06proto3')
  ,
  dependencies=[dgt__sdk_dot_protobuf_dot_batch__pb2.DESCRIPTOR,])




_GENESISDATA = _descriptor.Descriptor(
  name='GenesisData',
  full_name='GenesisData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='batches', full_name='GenesisData.batches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=102,
)

_GENESISDATA.fields_by_name['batches'].message_type = dgt__sdk_dot_protobuf_dot_batch__pb2._BATCH
DESCRIPTOR.message_types_by_name['GenesisData'] = _GENESISDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenesisData = _reflection.GeneratedProtocolMessageType('GenesisData', (_message.Message,), dict(
  DESCRIPTOR = _GENESISDATA,
  __module__ = 'dgt_sdk.protobuf.genesis_pb2'
  # @@protoc_insertion_point(class_scope:GenesisData)
  ))
_sym_db.RegisterMessage(GenesisData)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/client_batch_submit.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dgt_sdk.protobuf import batch_pb2 as dgt__sdk_dot_protobuf_dot_batch__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/client_batch_submit.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\027client_batch_submit_pb2'),
  serialized_pb=_b('\n*dgt_sdk/protobuf/client_batch_submit.proto\x1a\x1c\x64gt_sdk/protobuf/batch.proto\"\xbd\x02\n\x11\x43lientBatchStatus\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\t\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.ClientBatchStatus.Status\x12\x43\n\x14invalid_transactions\x18\x03 \x03(\x0b\x32%.ClientBatchStatus.InvalidTransaction\x1aT\n\x12InvalidTransaction\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x15\n\rextended_data\x18\x03 \x01(\x0c\"P\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\r\n\tCOMMITTED\x10\x01\x12\x0b\n\x07INVALID\x10\x02\x12\x0b\n\x07PENDING\x10\x03\x12\x0b\n\x07UNKNOWN\x10\x04\"3\n\x18\x43lientBatchSubmitRequest\x12\x17\n\x07\x62\x61tches\x18\x01 \x03(\x0b\x32\x06.Batch\"\xa9\x01\n\x19\x43lientBatchSubmitResponse\x12\x31\n\x06status\x18\x01 \x01(\x0e\x32!.ClientBatchSubmitResponse.Status\"Y\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x12\n\x0eINTERNAL_ERROR\x10\x02\x12\x11\n\rINVALID_BATCH\x10\x03\x12\x0e\n\nQUEUE_FULL\x10\x04\"L\n\x18\x43lientBatchStatusRequest\x12\x11\n\tbatch_ids\x18\x01 \x03(\t\x12\x0c\n\x04wait\x18\x02 \x01(\x08\x12\x0f\n\x07timeout\x18\x03 \x01(\r\"\xd3\x01\n\x19\x43lientBatchStatusResponse\x12\x31\n\x06status\x18\x01 \x01(\x0e\x32!.ClientBatchStatusResponse.Status\x12*\n\x0e\x62\x61tch_statuses\x18\x02 \x03(\x0b\x32\x12.ClientBatchStatus\"W\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x12\n\x0eINTERNAL_ERROR\x10\x02\x12\x0f\n\x0bNO_RESOURCE\x10\x05\x12\x0e\n\nINVALID_ID\x10\x08\x42\x32\n\x15sawtooth.sdk.protobufP\x01Z\x17\x63lient_batch_submit_pb2b\x06proto3')
  ,
  dependencies=[dgt__sdk_dot_protobuf_dot_batch__pb2.DESCRIPTOR,])



_CLIENTBATCHSTATUS_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientBatchStatus.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMITTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=314,
  serialized_end=394,
)
_sym_db.RegisterEnumDescriptor(_CLIENTBATCHSTATUS_STATUS)

_CLIENTBATCHSUBMITRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientBatchSubmitResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_BATCH', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUEUE_FULL', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=530,
  serialized_end=619,
)
_sym_db.RegisterEnumDescriptor(_CLIENTBATCHSUBMITRESPONSE_STATUS)

_CLIENTBATCHSTATUSRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ClientBatchStatusResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_RESOURCE', index=3, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ID', index=4, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=824,
  serialized_end=911,
)
_sym_db.RegisterEnumDescriptor(_CLIENTBATCHSTATUSRESPONSE_STATUS)


_CLIENTBATCHSTATUS_INVALIDTRANSACTION = _descriptor.Descriptor(
  name='InvalidTransaction',
  full_name='ClientBatchStatus.InvalidTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='ClientBatchStatus.InvalidTransaction.transaction_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='ClientBatchStatus.InvalidTransaction.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extended_data', full_name='ClientBatchStatus.InvalidTransaction.extended_data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=312,
)

_CLIENTBATCHSTATUS = _descriptor.Descriptor(
  name='ClientBatchStatus',
  full_name='ClientBatchStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch_id', full_name='ClientBatchStatus.batch_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientBatchStatus.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invalid_transactions', full_name='ClientBatchStatus.invalid_transactions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CLIENTBATCHSTATUS_INVALIDTRANSACTION, ],
  enum_types=[
    _CLIENTBATCHSTATUS_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=394,
)


_CLIENTBATCHSUBMITREQUEST = _descriptor.Descriptor(
  name='ClientBatchSubmitRequest',
  full_name='ClientBatchSubmitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='batches', full_name='ClientBatchSubmitRequest.batches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=447,
)


_CLIENTBATCHSUBMITRESPONSE = _descriptor.Descriptor(
  name='ClientBatchSubmitResponse',
  full_name='ClientBatchSubmitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientBatchSubmitResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTBATCHSUBMITRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=450,
  serialized_end=619,
)


_CLIENTBATCHSTATUSREQUEST = _descriptor.Descriptor(
  name='ClientBatchStatusRequest',
  full_name='ClientBatchStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch_ids', full_name='ClientBatchStatusRequest.batch_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wait', full_name='ClientBatchStatusRequest.wait', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='ClientBatchStatusRequest.timeout', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=621,
  serialized_end=697,
)


_CLIENTBATCHSTATUSRESPONSE = _descriptor.Descriptor(
  name='ClientBatchStatusResponse',
  full_name='ClientBatchStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ClientBatchStatusResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='batch_statuses', full_name='ClientBatchStatusResponse.batch_statuses', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTBATCHSTATUSRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=700,
  serialized_end=911,
)

_CLIENTBATCHSTATUS_INVALIDTRANSACTION.containing_type = _CLIENTBATCHSTATUS
_CLIENTBATCHSTATUS.fields_by_name['status'].enum_type = _CLIENTBATCHSTATUS_STATUS
_CLIENTBATCHSTATUS.fields_by_name['invalid_transactions'].message_type = _CLIENTBATCHSTATUS_INVALIDTRANSACTION
_CLIENTBATCHSTATUS_STATUS.containing_type = _CLIENTBATCHSTATUS
_CLIENTBATCHSUBMITREQUEST.fields_by_name['batches'].message_type = dgt__sdk_dot_protobuf_dot_batch__pb2._BATCH
_CLIENTBATCHSUBMITRESPONSE.fields_by_name['status'].enum_type = _CLIENTBATCHSUBMITRESPONSE_STATUS
_CLIENTBATCHSUBMITRESPONSE_STATUS.containing_type = _CLIENTBATCHSUBMITRESPONSE
_CLIENTBATCHSTATUSRESPONSE.fields_by_name['status'].enum_type = _CLIENTBATCHSTATUSRESPONSE_STATUS
_CLIENTBATCHSTATUSRESPONSE.fields_by_name['batch_statuses'].message_type = _CLIENTBATCHSTATUS
_CLIENTBATCHSTATUSRESPONSE_STATUS.containing_type = _CLIENTBATCHSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['ClientBatchStatus'] = _CLIENTBATCHSTATUS
DESCRIPTOR.message_types_by_name['ClientBatchSubmitRequest'] = _CLIENTBATCHSUBMITREQUEST
DESCRIPTOR.message_types_by_name['ClientBatchSubmitResponse'] = _CLIENTBATCHSUBMITRESPONSE
DESCRIPTOR.message_types_by_name['ClientBatchStatusRequest'] = _CLIENTBATCHSTATUSREQUEST
DESCRIPTOR.message_types_by_name['ClientBatchStatusResponse'] = _CLIENTBATCHSTATUSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientBatchStatus = _reflection.GeneratedProtocolMessageType('ClientBatchStatus', (_message.Message,), dict(

  InvalidTransaction = _reflection.GeneratedProtocolMessageType('InvalidTransaction', (_message.Message,), dict(
    DESCRIPTOR = _CLIENTBATCHSTATUS_INVALIDTRANSACTION,
    __module__ = 'dgt_sdk.protobuf.client_batch_submit_pb2'
    # @@protoc_insertion_point(class_scope:ClientBatchStatus.InvalidTransaction)
    ))
  ,
  DESCRIPTOR = _CLIENTBATCHSTATUS,
  __module__ = 'dgt_sdk.protobuf.client_batch_submit_pb2'
  # @@protoc_insertion_point(class_scope:ClientBatchStatus)
  ))
_sym_db.RegisterMessage(ClientBatchStatus)
_sym_db.RegisterMessage(ClientBatchStatus.InvalidTransaction)

ClientBatchSubmitRequest = _reflection.GeneratedProtocolMessageType('ClientBatchSubmitRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTBATCHSUBMITREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_batch_submit_pb2'
  # @@protoc_insertion_point(class_scope:ClientBatchSubmitRequest)
  ))
_sym_db.RegisterMessage(ClientBatchSubmitRequest)

ClientBatchSubmitResponse = _reflection.GeneratedProtocolMessageType('ClientBatchSubmitResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTBATCHSUBMITRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_batch_submit_pb2'
  # @@protoc_insertion_point(class_scope:ClientBatchSubmitResponse)
  ))
_sym_db.RegisterMessage(ClientBatchSubmitResponse)

ClientBatchStatusRequest = _reflection.GeneratedProtocolMessageType('ClientBatchStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTBATCHSTATUSREQUEST,
  __module__ = 'dgt_sdk.protobuf.client_batch_submit_pb2'
  # @@protoc_insertion_point(class_scope:ClientBatchStatusRequest)
  ))
_sym_db.RegisterMessage(ClientBatchStatusRequest)

ClientBatchStatusResponse = _reflection.GeneratedProtocolMessageType('ClientBatchStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTBATCHSTATUSRESPONSE,
  __module__ = 'dgt_sdk.protobuf.client_batch_submit_pb2'
  # @@protoc_insertion_point(class_scope:ClientBatchStatusResponse)
  ))
_sym_db.RegisterMessage(ClientBatchStatusResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Copyright 2018 DGT NETWORK INC © Stanislav Parsov
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# -----------------------------------------------------------------------------

import abc


class Block:
    def __init__(self, block):
        self.block_id = block.block_id
        self.previous_id = block.previous_id
        self.signer_id = block.signer_id
        self.block_num = block.block_num
        self.payload = block.payload
        self.summary = block.summary


class Service(metaclass=abc.ABCMeta):
    '''Provides methods that allow the consensus engine to issue commands
    and requests.'''

    # -- P2P --

    @abc.abstractmethod
    def send_to(self, peer_id, message_type, payload):
        '''Send a consensus message to a specific connected peer.

        Args:
            peer_id (bytes)
            message_type (str)
            payload (bytes)
        '''

    @abc.abstractmethod
    def broadcast(self, message_type, payload):
        '''Broadcast a message to all connected peers.

        Args:
            message_type (str)
            payload (bytes)
        '''

    # -- Block Creation --

    @abc.abstractmethod
    def initialize_block(self, previous_id):
        '''Initialize a new block with PREVIOUS_ID and begin adding batches to
        it. If no PREVIOUS_ID is specified, the current head will be
        used.

        Args:
            previous_id (bytes or None)
        '''

    @abc.abstractmethod
    def summarize_block(self):
        '''Stop adding batches to the current block and return a summary of its
        contents.

        Return:
            bytes
        '''

    @abc.abstractmethod
    def finalize_block(self, data):
        '''Insert the given consensus data into the block and sign it. If this
        call is successful, the consensus engine will receive the block
        afterwards.

        Args:
            data (bytes)

        Return:
            bytes
        '''

    @abc.abstractmethod
    def cancel_block(self):
        '''Stop adding batches to the current block and abandon it.'''

    # -- Block Directives --

    @abc.abstractmethod
    def check_blocks(self, priority):
        '''Update the prioritization of blocks to check to PRIORITY.

        Args:
            priority (list[bytes])
        '''

    @abc.abstractmethod
    def commit_block(self, block_id):
        '''Update the block that should be committed.

        Args:
            block_id (bytes)
        '''

    @abc.abstractmethod
    def ignore_block(self, block_id):
        '''Signal that this block is no longer being committed.

        Args:
            block_id (bytes)
        '''

    @abc.abstractmethod
    def fail_block(self, block_id):
        '''Mark this block as invalid from the perspective of consensus.

        Args:
            block_id (bytes)
        '''

    # -- Queries --

    @abc.abstractmethod
    def get_blocks(self, block_ids):
        '''Retrive consensus-related information about blocks.

        Args:
            block_ids (list[bytes])

        Return:
            dict[bytes, block]
        '''

    @abc.abstractmethod
    def get_chain_head(self):
        '''Retrieve consensus-related information about the chain head.

        Return:
            block
        '''

    @abc.abstractmethod
    def get_settings(self, block_id, settings):
        '''Read the value of settings as of the given block.

        Args:
            block_id (bytes)
            settings (list[str])

        Return:
            dict[str, str]
        '''

    @abc.abstractmethod
    def get_state(self, block_id, addresses):
        '''Read values in state as of the given block.

        Args:
            block_id (bytes)
            addresses (list[str])

        Return:
            dict[str, bytes]
        '''



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/transaction_receipt.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dgt_sdk.protobuf import events_pb2 as dgt__sdk_dot_protobuf_dot_events__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/transaction_receipt.proto',
  package='',
  syntax='proto3',
  serialized_options=_b('\n\025sawtooth.sdk.protobufP\001Z\017txn_receipt_pb2'),
  serialized_pb=_b('\n*dgt_sdk/protobuf/transaction_receipt.proto\x1a\x1d\x64gt_sdk/protobuf/events.proto\"\x8a\x01\n\x12TransactionReceipt\x12#\n\rstate_changes\x18\x01 \x03(\x0b\x32\x0c.StateChange\x12\x16\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x06.Event\x12\x0c\n\x04\x64\x61ta\x18\x03 \x03(\x0c\x12\x16\n\x0etransaction_id\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\r\"{\n\x0bStateChange\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x1f\n\x04type\x18\x03 \x01(\x0e\x32\x11.StateChange.Type\"+\n\x04Type\x12\x0e\n\nTYPE_UNSET\x10\x00\x12\x07\n\x03SET\x10\x01\x12\n\n\x06\x44\x45LETE\x10\x02\"6\n\x0fStateChangeList\x12#\n\rstate_changes\x18\x01 \x03(\x0b\x32\x0c.StateChangeB*\n\x15sawtooth.sdk.protobufP\x01Z\x0ftxn_receipt_pb2b\x06proto3')
  ,
  dependencies=[dgt__sdk_dot_protobuf_dot_events__pb2.DESCRIPTOR,])



_STATECHANGE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='StateChange.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TYPE_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELETE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=298,
  serialized_end=341,
)
_sym_db.RegisterEnumDescriptor(_STATECHANGE_TYPE)


_TRANSACTIONRECEIPT = _descriptor.Descriptor(
  name='TransactionReceipt',
  full_name='TransactionReceipt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state_changes', full_name='TransactionReceipt.state_changes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='events', full_name='TransactionReceipt.events', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='TransactionReceipt.data', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_id', full_name='TransactionReceipt.transaction_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='TransactionReceipt.timestamp', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=216,
)


_STATECHANGE = _descriptor.Descriptor(
  name='StateChange',
  full_name='StateChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='StateChange.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='StateChange.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='StateChange.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATECHANGE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=341,
)


_STATECHANGELIST = _descriptor.Descriptor(
  name='StateChangeList',
  full_name='StateChangeList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state_changes', full_name='StateChangeList.state_changes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=343,
  serialized_end=397,
)

_TRANSACTIONRECEIPT.fields_by_name['state_changes'].message_type = _STATECHANGE
_TRANSACTIONRECEIPT.fields_by_name['events'].message_type = dgt__sdk_dot_protobuf_dot_events__pb2._EVENT
_STATECHANGE.fields_by_name['type'].enum_type = _STATECHANGE_TYPE
_STATECHANGE_TYPE.containing_type = _STATECHANGE
_STATECHANGELIST.fields_by_name['state_changes'].message_type = _STATECHANGE
DESCRIPTOR.message_types_by_name['TransactionReceipt'] = _TRANSACTIONRECEIPT
DESCRIPTOR.message_types_by_name['StateChange'] = _STATECHANGE
DESCRIPTOR.message_types_by_name['StateChangeList'] = _STATECHANGELIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TransactionReceipt = _reflection.GeneratedProtocolMessageType('TransactionReceipt', (_message.Message,), dict(
  DESCRIPTOR = _TRANSACTIONRECEIPT,
  __module__ = 'dgt_sdk.protobuf.transaction_receipt_pb2'
  # @@protoc_insertion_point(class_scope:TransactionReceipt)
  ))
_sym_db.RegisterMessage(TransactionReceipt)

StateChange = _reflection.GeneratedProtocolMessageType('StateChange', (_message.Message,), dict(
  DESCRIPTOR = _STATECHANGE,
  __module__ = 'dgt_sdk.protobuf.transaction_receipt_pb2'
  # @@protoc_insertion_point(class_scope:StateChange)
  ))
_sym_db.RegisterMessage(StateChange)

StateChangeList = _reflection.GeneratedProtocolMessageType('StateChangeList', (_message.Message,), dict(
  DESCRIPTOR = _STATECHANGELIST,
  __module__ = 'dgt_sdk.protobuf.transaction_receipt_pb2'
  # @@protoc_insertion_point(class_scope:StateChangeList)
  ))
_sym_db.RegisterMessage(StateChangeList)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
